@@ -67,11 +67,10 @@ def assert_pd_equality(
         raise BeavisDataFramesNotEqualError("\n" + t.get_string())
 
 
-def assert_approx_pd_equality(
-    df1, df2, precision, check_index=True, check_dtype=True
-):
+def assert_approx_pd_equality(df1, df2, precision, check_index=True, check_dtype=True):
     def approx_equality(a, b):
         return math.isclose(a, b, rel_tol=precision)
+
     dtypes = df1.dtypes
     equality_funs = {}
     for k, v in dtypes.items():
@@ -135,10 +134,3 @@ def assert_pd_column_equality(df, col_name1, col_name2, equality_fun=None):
                 t.add_row([str(elements[0]), str(elements[1])])
         raise BeavisColumnsNotEqualError("\n" + t.get_string())
 
-
-def assert_dd_equality(df1, df2, check_index=True, check_dtype=True):
-    assert_pd_equality(df1.compute(), df2.compute(), check_index, check_dtype)
-
-
-def assert_dd_column_equality(df, col_name1, col_name2):
-    assert_pd_column_equality(df.compute(), col_name1, col_name2)
